@@ -19,8 +19,8 @@ Usage::
     list_backend_jobs_paginator: ListBackendJobsPaginator = client.get_paginator("list_backend_jobs")
     ```
 """
-from mypy_boto3_amplifybackend.client import AmplifyBackendClient
-from mypy_boto3_amplifybackend.paginator import ListBackendJobsPaginator
+from .client import AmplifyBackendClient
+from .paginator import ListBackendJobsPaginator
 
 Client = AmplifyBackendClient
 
